PayloadConfig

Struct PayloadConfig 

pub struct PayloadConfig {
    limit: usize,
    mimetype: Option<Mime>,
}
Configuration for request payloads.

Applies to the built-in Bytes and String extractors. Note that the Payload extractor does not automatically check conformance with this configuration to allow more flexibility when building extractors on top of Payload.

By default, the payload size limit is 256kB and there is no mime type condition.

To use this, add an instance of it to your app, scope or resource through the associated .app_data() method.

Fields

limit: usizemimetype: Option<Mime>

Implementations



impl PayloadConfig

pub fn new(limit: usize) -> PayloadConfig

Create new instance with a size limit (in bytes) and no mime type condition.

pub fn limit(self, limit: usize) -> PayloadConfig

Set maximum accepted payload size in bytes. The default limit is 256KiB.

pub fn mimetype(self, mt: Mime) -> PayloadConfig

Set required mime type of the request. By default mime type is not enforced.